exceptiontools.ExtraPitchError
==============================

.. abjad-lineage:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError

.. autoclass:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.ExtraPitchError.ExtraPitchError.__unicode__
   :noindex:
